---
name: Design change
about: Propose a change to the design of the CLI
title: ''
labels: design
assignees: ''

---

**What is the current behavior of feature you are looking to change?**
<!-- A clear and concise description of what the behavior of the ilab feature is currently -->

**What is the proposed behavior of feature you are looking to change?**
<!-- A clear and concise description of what the behavior of the ilab feature would look like after your proposed change -->

**What is the benefit of the design change you are proposing?**
<!-- Justify your call to change the CLI here -->

**If applicable, how would backwards-compatability be handled?**
<!-- Feel free to remove this section if this does not apply to your design change -->

**Additional context**
<!-- Add any other context or screenshots about the design change here. -->
